from django.core.files.storage import FileSystemStorage
from django.db import models

from core import settings


class StatusChoices(models.TextChoices):
    RESOLVE = 'Документ отправлен на подпись, проверьте Вашу почту'
    REJECT = 'Не удалось отправить документ на подпись'
    DEFAULT = 'Документ ожидает подтверждения отправки на подпись'


class SignerInfo(models.Model):
    signer_name = models.CharField(
        max_length=20,
        null=False,
        blank=False,
        verbose_name='Имя',
    )
    signer_surname = models.CharField(
        max_length=20,
        null=False,
        blank=False,
        verbose_name='Фамилия',
    )
    signer_email = models.EmailField(
        max_length=254,
        verbose_name='Почта',
    )
    status = models.CharField(
        max_length=100,
        null=False,
        blank=False,
        choices=StatusChoices.choices,
        default=StatusChoices.DEFAULT,
        verbose_name='Статус заявки',
    )

    def __str__(self):
        return f'{self.signer_name}  {self.signer_email}'
